darkhistory.electrons.ics — DarkHistory documentation

# darkhistory.electrons.ics

Inverse Compton scattering modules.

Modules

`BE_integrals` | Integrals over the Bose-Einstein distribution.
`engloss_diff_terms` | Functions for computing the ICS energy loss spectrum by small parameter expansion.
`ics_cooling` | Electron cooling through ICS.
`ics_engloss_spectrum` | Nonrelativistic ICS spectrum after integrating over CMB.
`ics_spectrum` | Inverse Compton scattering spectrum after integrating over CMB.
`nonrel_diff_terms` | Functions for computing the nonrelativistic ICS spectrum by beta expansion.

#### Previous topic

darkhistory.electrons.positronium.weighted_photon_spec

#### Next topic

darkhistory.electrons.ics.BE_integrals

### This Page

Show Source